package com.ghy.goods.mapper;
import java.util.List;
import com.ghy.goods.domain.InsuranceManager;
import org.apache.ibatis.annotations.Param;

/**
 * 保险管理Mapper接口
 *
 * @author clunt
 * @date 2024-09-25
 */
public interface InsuranceManagerMapper
{
    /**
     * 查询保险管理
     *
     * @param id 保险管理主键
     * @return 保险管理
     */
    public InsuranceManager selectInsuranceManagerById(Long id);

    /**
     * 查询保险管理列表
     *
     * @param insuranceManager 保险管理
     * @return 保险管理集合
     */
    public List<InsuranceManager> selectInsuranceManagerList(InsuranceManager insuranceManager);

    /**
     * 新增保险管理
     *
     * @param insuranceManager 保险管理
     * @return 结果
     */
    public int insertInsuranceManager(InsuranceManager insuranceManager);

    /**
     * 修改保险管理
     *
     * @param insuranceManager 保险管理
     * @return 结果
     */
    public int updateInsuranceManager(InsuranceManager insuranceManager);

    /**
     * 删除保险管理
     *
     * @param id 保险管理主键
     * @return 结果
     */
    public int deleteInsuranceManagerById(Long id);

    /**
     * 批量删除保险管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInsuranceManagerByIds(String[] ids);

    List<InsuranceManager> selectByIds(@Param("ids") List<Long> ids);

}
